@@ -8,12 +8,15 @@
 
 #include <QDBusObjectPath>
 #include <QMessageBox>
+#include <QProcess>
 
 #include <KActivities/Consumer>
+#include <KApplicationTrader>
+#include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KPasswordDialog>
 #include <KPluginFactory>
-#include <KRun>
+#include <KService>
 
 #include "engine/commandresult.h"
 #include "engine/vault.h"
@@ -28,7 +31,7 @@
 #include <asynqt/operations/listen.h>
 
 #include <config-plasma-vault.h>
-#ifdef HAVE_NETWORKMANAGER
+#if HAVE_NETWORKMANAGER
 #include <NetworkManagerQt/Manager>
 #else
 namespace NetworkManager
@@ -155,7 +158,7 @@ void PlasmaVaultService::requestImportVault()
 void PlasmaVaultService::slotRegistered(const QDBusObjectPath &path)
 {
     if (path.path() == QLatin1String("/modules/plasmavault")) {
-        emit registered();
+        Q_EMIT registered();
     }
 }
 
@@ -179,7 +182,7 @@ void PlasmaVaultService::registerVault(Vault *vault)
     connect(vault, &Vault::messageChanged, this, &PlasmaVaultService::onVaultMessageChanged);
     connect(vault, &Vault::infoChanged, this, &PlasmaVaultService::onVaultInfoChanged);
 
-    emit vaultAdded(vault->info());
+    Q_EMIT vaultAdded(vault->info());
 
     if (vault->status() == VaultInfo::Opened) {
         d->openVaults << vault->device();
@@ -193,7 +196,7 @@ void PlasmaVaultService::forgetVault(Vault *vault)
     // and therefore can not inhibit networking
     // ... d->savedNetworkingState ...
 
-    emit vaultRemoved(vault->device().data());
+    Q_EMIT vaultRemoved(vault->device().data());
 
     d->knownVaults.remove(vault->device());
     vault->deleteLater();
@@ -209,13 +212,13 @@ void PlasmaVaultService::onVaultStatusChanged(VaultInfo::Status status)
     } else if (status == VaultInfo::Opened) {
         d->openVaults << vault->device();
         if (d->openVaults.size() == 1) {
-            emit hasOpenVaultsChanged(true);
+            Q_EMIT hasOpenVaultsChanged(true);
         }
 
     } else {
         d->openVaults.remove(vault->device());
         if (d->openVaults.isEmpty()) {
-            emit hasOpenVaultsChanged(false);
+            Q_EMIT hasOpenVaultsChanged(false);
         }
     }
 
@@ -246,20 +249,20 @@ void PlasmaVaultService::onVaultStatusChanged(VaultInfo::Status status)
         d->restoreNetworkingState();
     }
 
-    emit vaultChanged(vault->info());
+    Q_EMIT vaultChanged(vault->info());
 }
 
 void PlasmaVaultService::onVaultInfoChanged()
 {
     const auto vault = static_cast<Vault *>(sender());
-    emit vaultChanged(vault->info());
+    Q_EMIT vaultChanged(vault->info());
 }
 
 void PlasmaVaultService::onVaultMessageChanged(const QString &message)
 {
     Q_UNUSED(message);
     const auto vault = static_cast<Vault *>(sender());
-    emit vaultChanged(vault->info());
+    Q_EMIT vaultChanged(vault->info());
 }
 
 template<typename OnAccepted, typename OnRejected>
@@ -309,7 +312,7 @@ void PlasmaVaultService::openVault(const QString &device)
         showPasswordMountDialog(
             vault,
             [this, vault, stopInhibiting] {
-                emit vaultChanged(vault->info());
+                Q_EMIT vaultChanged(vault->info());
                 stopInhibiting();
             },
             [this, vault, stopInhibiting] {
@@ -352,16 +355,31 @@ void PlasmaVaultService::forceCloseVault(const QString &device)
 
 void PlasmaVaultService::openVaultInFileManager(const QString &device)
 {
+    auto openFileManager = [this](const auto &vault) {
+        KService::Ptr service = KApplicationTrader::preferredService(QStringLiteral("inode/directory"));
+
+        // A hack to always open a new dolphin window
+        // BUG: 445542
+        // https://bugs.kde.org/show_bug.cgi?id=445542
+        if (service->desktopEntryName() == QStringLiteral("org.kde.dolphin")) {
+            service->setExec(service->exec() + QStringLiteral(" --new-window"));
+        }
+
+        auto *job = new KIO::ApplicationLauncherJob(service, this);
+        job->setUrls({QUrl::fromLocalFile((QString)vault->mountPoint().data())});
+        job->start();
+    };
+
     if (auto vault = d->vaultFor(device)) {
         if (vault->isOpened()) {
-            new KRun(QUrl::fromLocalFile((QString)vault->mountPoint().data()), nullptr);
+            openFileManager(vault);
 
         } else {
             showPasswordMountDialog(
                 vault,
-                [this, vault] {
-                    emit vaultChanged(vault->info());
-                    new KRun(QUrl::fromLocalFile((QString)vault->mountPoint().data()), nullptr);
+                [this, vault, openFileManager] {
+                    Q_EMIT vaultChanged(vault->info());
+                    openFileManager(vault);
                 },
                 [this, vault] {
                     if (vault->status() != VaultInfo::Opened && d->savedNetworkingState) {
@@ -468,7 +486,7 @@ void PlasmaVaultService::onActivityRemoved(const QString &removedActivity)
         if (vaultActivities.removeAll(removedActivity) > 0) {
             vault->setActivities(vaultActivities);
             vault->saveConfiguration();
-            emit vaultChanged(vault->info());
+            Q_EMIT vaultChanged(vault->info());
         }
     }
 }
